==> ordering-core-0.1.14.tgz: package/lib/esm/mainService.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as listener from './wsListener';
import * as orderService from './orderService';
import * as orderStore from './orderStore';
export function orderChangesListener(BASE_URL, TENANT, VENUE, authDataProvider, 
//refreshTokenHandler: IRefreshTokenStorageHandler,
onOrderUpdatedCallback, _onAuthFailureCallback, enableKDS) {
    return new Promise((resolve, reject) => {
        orderStore.setOrderStoreUpdatedCallback(onOrderUpdatedCallback);
        const params = {
            baseURL: BASE_URL,
            tenant: TENANT,
            venue: VENUE,
            authDataProvider: authDataProvider,
            onConnectedAsync: (accessToken) => __awaiter(this, void 0, void 0, function* () {
                let orders;
                if (!enableKDS) {
                    //console.log('-- pull orders for user -- ');
                    orders = yield orderService.pullOrdersForUser(BASE_URL, accessToken);
                }
                else {
                    // KDS version
                    //console.log('-- pull orders KDS -- ');
                    orders = yield orderService.pullOrders(BASE_URL, VENUE, accessToken);
                }
                for (const order of orders) {
                    orderStore.onOrderUpdate(order);
                }
                resolve();
            }),
            onDisconnectAsync: () => __awaiter(this, void 0, void 0, function* () {
                //console.log('ws disconnected');
            }),
            onKDSMessageAsync: null,
            onOrdersUpdateAsync: (order) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`new or updated order [${order.id}]`);
                orderStore.onOrderUpdate(order);
            }),
            onNotificationAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`NOTIFICATION: ${JSON.stringify(message)}`);
                orderStore.onOrderError(message);
            }),
            onAuthFailure: () => __awaiter(this, void 0, void 0, function* () {
                console.log('------------- MANUAL AUTH REQUIRED ----------------- ');
                if (_onAuthFailureCallback)
                    yield _onAuthFailureCallback();
            }),
            enableKDS,
        };
        if (enableKDS) {
            params.onKDSMessageAsync = (message) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`MESSAGE  order [${message.id}]`);
                orderStore.onOrderUpdate(message);
            });
        }
        listener.connectWebSockets(params);
    });
}

==> ordering-core-0.2.5.tgz: package/lib/esm/mainService.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as listener from './wsListener';
import * as orderService from './orderService';
import * as orderStore from './orderStore';
export function orderChangesListener(BASE_URL, TENANT, VENUE, authDataProvider, 
//refreshTokenHandler: IRefreshTokenStorageHandler,
onOrderUpdatedCallback, _onAuthFailureCallback, enableKDS) {
    return new Promise((resolve, reject) => {
        orderStore.setOrderStoreUpdatedCallback(onOrderUpdatedCallback);
        const params = {
            baseURL: BASE_URL,
            tenant: TENANT,
            venue: VENUE,
            authDataProvider: authDataProvider,
            onConnectedAsync: (accessToken) => __awaiter(this, void 0, void 0, function* () {
                let orders;
                if (!enableKDS) {
                    //console.log('-- pull orders for user -- ');
                    orders = yield orderService.pullOrdersForUser(BASE_URL, accessToken);
                }
                else {
                    // KDS version
                    //console.log('-- pull orders KDS -- ');
                    orders = yield orderService.pullOrders(BASE_URL, VENUE, accessToken);
                }
                for (const order of orders) {
                    orderStore.onOrderUpdate(order, enableKDS, VENUE);
                }
                resolve();
            }),
            onDisconnectAsync: () => __awaiter(this, void 0, void 0, function* () {
                console.log('ws disconnected');
            }),
            onKDSMessageAsync: null,
            onOrdersUpdateAsync: (order) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`new or updated order [${order.id}]`);
                orderStore.onOrderUpdate(order, enableKDS, VENUE);
            }),
            onNotificationAsync: (message) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`NOTIFICATION: ${JSON.stringify(message)}`);
                orderStore.onOrderError(message);
            }),
            onAuthFailure: () => __awaiter(this, void 0, void 0, function* () {
                console.log('------------- MANUAL AUTH REQUIRED ----------------- ');
                if (_onAuthFailureCallback)
                    yield _onAuthFailureCallback();
            }),
            enableKDS,
        };
        if (enableKDS) {
            params.onKDSMessageAsync = (message) => __awaiter(this, void 0, void 0, function* () {
                //console.log(`MESSAGE  order [${message.id}]`);
                orderStore.onOrderUpdate(message, enableKDS, VENUE);
            });
        }
        listener.connectWebSockets(params);
    });
}
